/* ===================================================================================================
* WARNING – This file is part of the base implementation for WebMaker, so it should not be edited or changed for any project.
* These files are replaced if a project is re-imported to the WebMaker Studio or migrated to a new version of the product.
* For guidance on 'How do I override or clone Hyfinity webapp files such as CSS & javascript?', please read the following relevant FAQ entry:
* http://www.hyfinity.net/faq/index/solution_id/1113
==================================================================================================== */

/*
 * collapsiblecontent.js
 *
 * Functions for the collapsible content pallete section
 *
 * Company: Hyfinity Ltd
 * Copyright (c) 2010
 */

hyf.collapsiblecontent = {};

/**
 * This function is called when the page loads to ensure that any collapsible sections are presented visible or hidden as appropriate.
 * Each collapsible secition has an anchor that has a class that controls the visibility of two groups. The collapsed group is an optional group that may not be used.
 * @param container {Group_Name} (optional) The group container that is an HTML DIV to look in for collapsible sections to initialise.  If not provided, the whole page will be processed.
 *
 * @author Hyfinity Limited
 */
hyf.collapsiblecontent.init = function(container)
{
    if (!container)
    {
        container = document.body;
    }
    if (typeof(container) == 'string')
    {
        container = document.getElementById(container);
    }

    //first process all the sections to be shown hidden initially based on the class names
    dojo.query('.collapsibleSection A.toggleHidden', container).forEach(function(objDisplayState) {
        //Check that this control has not already been initialised
        if (dojo.query('.showHideContainer', objDisplayState).length == 0)
        {
            //Add a span for the anchor that defines the current state and give it a label defined as a custom attribute
            var labelString = objDisplayState.getAttribute('showLabel');
            if (labelString.substr(labelString.length - 6) != "&nbsp;") //make sure we have a non breaking space at the end
                labelString += "&nbsp;"
            dojo.query('span',objDisplayState)[0].innerHTML = "<span class='showHideContainer'>" + labelString + "</span>" +
                                                                dojo.query('span',objDisplayState)[0].innerHTML;
            //Ensure all collapsible sections are prepared, as the default display is for the main details to be visible
            //and the collapsed group to be hidden.  This is so that the user sees the important data with script disabled.
            //For this scenario we want the opposite default display, so need to toggle the hide class on both groups
            var objParentNode = objDisplayState;
            while ((objParentNode !=null) && (!dojo.hasClass(objParentNode, 'collapsibleSection')))
            {
                objParentNode = objParentNode.parentNode;
            }
            if (objParentNode != null)
            {
                dojo.query('> .collapsibleContent, > .collapsedContent', objParentNode).toggleClass('hide');
            }
        }
    });

    //now process all the sections to be shown visible initially
    dojo.query('.collapsibleSection A.toggleVisible', container).forEach(function(objDisplayState) {
        //Check that this control has not already been initialised
        if (dojo.query('.showHideContainer', objDisplayState).length == 0)
        {
            var labelString = objDisplayState.getAttribute('hideLabel');
            if (labelString.substr(labelString.length - 6) != "&nbsp;") //make sure we have a non breaking space at the end
                labelString += "&nbsp;"
            dojo.query('span',objDisplayState)[0].innerHTML = "<span class='showHideContainer'>" + labelString + "</span>" +
                                                                dojo.query('span',objDisplayState)[0].innerHTML;
        }
    });
}

/**
 * This function is called for the toggling anchor to change the visibility state of the groups from their current state.
 * @param toggleAnchor {Field_Name} The Hyperlink (HTML anchor) that was clicked within the collapsible section.
 *
 * @author Hyfinity Limited
 */
hyf.collapsiblecontent.toggle = function(toggleAnchor)
{
    if (typeof(toggleAnchor) == 'string')
    {
        toggleAnchor = document.getElementById(toggleAnchor);
    }
    // return if mandatory paramters are missing.
    if (toggleAnchor == null)
    {
        return;
    }

    var currentState = (dojo.hasClass(toggleAnchor, 'toggleHidden')) ? 'Hidden' : 'Visible';
    var displayText = dojo.query('.showHideContainer', toggleAnchor)[0];

    var labelString = ''
    if (currentState == 'Visible')
        labelString = toggleAnchor.getAttribute('showLabel');
    else
       labelString = toggleAnchor.getAttribute('hideLabel');

    if (labelString.substr(labelString.length - 6) != "&nbsp;")
        labelString += "&nbsp;"

    displayText.innerHTML = labelString;

    dojo.toggleClass(toggleAnchor, 'toggleVisible');
    dojo.toggleClass(toggleAnchor, 'toggleHidden');

    var objParentNode = toggleAnchor;
    while ((objParentNode !=null) && (!dojo.hasClass(objParentNode, 'collapsibleSection')))
    {
        objParentNode = objParentNode.parentNode;
    }
    if (objParentNode != null)
    {
            dojo.query('> .collapsibleContent, > .collapsedContent', objParentNode).forEach(function(group) {
                hyf.util.toggleComponent(group, null, true);
        } );
    }
}


/**
 * This function is called to set the visibility state of the collapsible section.
 * @param toggleAnchor {Field_Name} The Hyperlink (HTML anchor) that was clicked within the collapsible section.
 * @param setVisible {boolean} true will make it visible if not already visible. false will hide it.
 *
 * @author Hyfinity Limited
 */
hyf.collapsiblecontent.setVisibility = function(toggleAnchor,setVisible)
{
    if (typeof(toggleAnchor) == 'string')
    {
        toggleAnchor = document.getElementById(toggleAnchor);
    }
    // return if mandatory paramters are missing.
    if ((toggleAnchor == null) || (setVisible == null))
    {
        return;
    }
    if (typeof(setVisible) != 'boolean')
        return;

    var currentState = (dojo.hasClass(toggleAnchor, 'toggleHidden')) ? 'Hidden' : 'Visible';
    var displayText = dojo.query('.showHideContainer', toggleAnchor)[0];

    var labelString = ''
    if ((currentState == 'Visible') && (setVisible == false))
    {
        labelString = toggleAnchor.getAttribute('showLabel');
    if (labelString.substr(labelString.length - 6) != "&nbsp;")
        labelString += "&nbsp;"

        displayText.innerHTML = labelString;

        dojo.toggleClass(toggleAnchor, 'toggleVisible');
        dojo.toggleClass(toggleAnchor, 'toggleHidden');

        var objParentNode = toggleAnchor;
        while ((objParentNode !=null) && (!dojo.hasClass(objParentNode, 'collapsibleSection')))
        {
        objParentNode = objParentNode.parentNode;
        }
        if (objParentNode != null)
        {
            dojo.query('> .collapsibleContent, > .collapsedContent', objParentNode).forEach(function(group) {
            hyf.util.hideComponent(group, true);
        } );
        }
    }

    if ((currentState == 'Hidden') && (setVisible == true))
    {
        labelString = toggleAnchor.getAttribute('hideLabel');
        if (labelString.substr(labelString.length - 6) != "&nbsp;")
            labelString += "&nbsp;"

        displayText.innerHTML = labelString;

        dojo.toggleClass(toggleAnchor, 'toggleVisible');
        dojo.toggleClass(toggleAnchor, 'toggleHidden');

        var objParentNode = toggleAnchor;
        while ((objParentNode !=null) && (!dojo.hasClass(objParentNode, 'collapsibleSection')))
        {
        objParentNode = objParentNode.parentNode;
        }
        if (objParentNode != null)
        {
            dojo.query('> .collapsibleContent, > .collapsedContent', objParentNode).forEach(function(group) {
            hyf.util.showComponent(group, true);
        } );
        }
    }
}

//Ensure the initialistaion function is called when needed, by connecting to the widgetsParsed hook
//This will be called after initialisation any dojo widgets when needed (eg on page load, or when partial pages are loaded)
//which matches the times we need to look for new collapsible sections.
dojo.connect(hyf.hooks, 'widgetsParsed', hyf.collapsiblecontent.init);